@@ -1,5 +1,31 @@
 var NAVTREEINDEX111 =
 {
+"points.html#secPtIndexIterators":[7,6,2],
+"points.html#secPtIndexIterators":[0,0,6,2],
+"points.html#secPtLocality":[7,3],
+"points.html#secPtLocality":[0,0,3],
+"points.html#secPtOverview":[7,1],
+"points.html#secPtOverview":[0,0,1],
+"points.html#secPtPointDataTree":[7,5,1],
+"points.html#secPtPointDataTree":[0,0,5,1],
+"points.html#secPtPointIndexTree":[7,5,0],
+"points.html#secPtPointIndexTree":[0,0,5,0],
+"points.html#secPtPointTree":[7,5],
+"points.html#secPtPointTree":[0,0,5],
+"points.html#secPtSpaceAndTrans":[7,7],
+"points.html#secPtSpaceAndTrans":[0,0,7],
+"points.html#secPtSparsity":[7,6],
+"points.html#secPtSparsity":[0,0,6],
+"points.html#secPtTypedAttributeArray":[7,4,0],
+"points.html#secPtTypedAttributeArray":[0,0,4,0],
+"points_2PointAdvect_8h.html":[16,0,2,2,7],
+"points_2PointAdvect_8h_source.html":[16,0,2,2,7],
+"points_2PointScatter_8h.html":[16,0,2,2,21],
+"points_2PointScatter_8h_source.html":[16,0,2,2,21],
+"python.html":[8],
+"python.html#sPyAccessors":[8,3],
+"python.html#sPyBasics":[8,1],
+"python.html#sPyContents":[8,0],
 "python.html#sPyCppAPI":[8,7],
 "python.html#sPyHandlingMetadata":[8,2],
 "python.html#sPyIteration":[8,4],
@@ -223,31 +249,5 @@ var NAVTREEINDEX111 =
 "structcxx14_1_1make__index__sequence.html":[15,0,0,1],
 "structcxx14_1_1make__index__sequence_3_010_00_01Is_8_8_8_01_4.html":[14,0,0,2],
 "structcxx14_1_1make__index__sequence_3_010_00_01Is_8_8_8_01_4.html":[15,0,0,2],
-"structnanovdb_1_1BitArray.html":[14,0,5,2],
-"structnanovdb_1_1BitArray.html":[15,0,3,2],
-"structnanovdb_1_1BitArray_3_0116_01_4.html":[14,0,5,3],
-"structnanovdb_1_1BitArray_3_0116_01_4.html":[15,0,3,3],
-"structnanovdb_1_1BitArray_3_0116_01_4.html#ae2251e09460138f434f445cab7824c08":[14,0,5,3,0],
-"structnanovdb_1_1BitArray_3_0116_01_4.html#ae2251e09460138f434f445cab7824c08":[15,0,3,3,0],
-"structnanovdb_1_1BitArray_3_0132_01_4.html":[14,0,5,4],
-"structnanovdb_1_1BitArray_3_0132_01_4.html":[15,0,3,4],
-"structnanovdb_1_1BitArray_3_0132_01_4.html#a0251ac0c51aa69a1a5f25044b269eae1":[14,0,5,4,0],
-"structnanovdb_1_1BitArray_3_0132_01_4.html#a0251ac0c51aa69a1a5f25044b269eae1":[15,0,3,4,0],
-"structnanovdb_1_1BitArray_3_0164_01_4.html":[14,0,5,5],
-"structnanovdb_1_1BitArray_3_0164_01_4.html":[15,0,3,5],
-"structnanovdb_1_1BitArray_3_0164_01_4.html#af3e2644dc8b717cc20da528c6de31cb3":[14,0,5,5,0],
-"structnanovdb_1_1BitArray_3_0164_01_4.html#af3e2644dc8b717cc20da528c6de31cb3":[15,0,3,5,0],
-"structnanovdb_1_1BitArray_3_018_01_4.html":[14,0,5,6],
-"structnanovdb_1_1BitArray_3_018_01_4.html":[15,0,3,6],
-"structnanovdb_1_1BitArray_3_018_01_4.html#a51fb244e2361235b2287e9d140c4062d":[14,0,5,6,0],
-"structnanovdb_1_1BitArray_3_018_01_4.html#a51fb244e2361235b2287e9d140c4062d":[15,0,3,6,0],
-"structnanovdb_1_1BufferTraits.html":[14,0,5,8],
-"structnanovdb_1_1BufferTraits.html":[15,0,3,8],
-"structnanovdb_1_1BufferTraits.html#ae2c7013b5a04d0316a3517ca603f3bdd":[14,0,5,8,0],
-"structnanovdb_1_1BufferTraits.html#ae2c7013b5a04d0316a3517ca603f3bdd":[15,0,3,8,0],
-"structnanovdb_1_1BuildToValueMap.html":[14,0,5,9],
-"structnanovdb_1_1BuildToValueMap.html":[15,0,3,9],
-"structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,9,0],
-"structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,10,0],
-"structnanovdb_1_1BuildToValueMap.html#a19462713b2aab2dae2c87c15f262c1df":[14,0,5,11,0]
+"structnanovdb_1_1BitArray.html":[14,0,5,2]
 };
